Class: SlimLint::Linter::ConsecutiveControlStatements

Inherits:
Linter
  • Object
show all
Includes:
SlimLint::LinterRegistry
Defined in:
lib/slim_lint/linter/consecutive_control_statements.rb

Overview

Searches for more than an allowed number of consecutive control code statements that could be condensed into a :ruby filter.

Method Summary

Methods included from SlimLint::LinterRegistry

extract_linters_from, included, linter_names