Class: SlimLint::Linter::EmptyLines

Inherits:
Linter
  • Object
show all
Includes:
SlimLint::LinterRegistry
Defined in:
lib/slim_lint/linter/empty_lines.rb

Overview

This linter checks for two or more consecutive blank lines and for the first blank line in file.

Method Summary

Methods included from SlimLint::LinterRegistry

extract_linters_from, included, linter_names