Class: SlimLint::Linter::ConsecutiveControlStatements
- Inherits:
-
Linter
- Object
- Linter
- SlimLint::Linter::ConsecutiveControlStatements
- Includes:
- SlimLint::LinterRegistry
- Defined in:
- lib/slim_lint/linter/consecutive_control_statements.rb
Overview
Searches for more than an allowed number of consecutive control code statements that could be condensed into a :ruby filter.