Class: SlimLint::Linter::ControlStatementSpacing
- Inherits:
-
Linter
- Object
- Linter
- SlimLint::Linter::ControlStatementSpacing
- Includes:
- SlimLint::LinterRegistry
- Defined in:
- lib/slim_lint/linter/control_statement_spacing.rb
Overview
Checks for missing or superfluous spacing before and after control statements.
Constant Summary collapse
- MESSAGE_OUTPUT =
'Please add a space before and after the `=`'- MESSAGE_CONTROL =
'Please add a space after the `-`'