Class: SlimLint::Linter::EmptyLines
- Inherits:
-
Linter
- Object
- Linter
- SlimLint::Linter::EmptyLines
- Includes:
- SlimLint::LinterRegistry
- Defined in:
- lib/slim_lint/linter/empty_lines.rb
Overview
This linter checks for two or more consecutive blank lines and for the first blank line in file.